\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{thesistemplate}[2016/01/01 TL-MUET B.E. Thesis Class File]

\PassOptionsToClass{a4paper,10pt}{report}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{report}}
\ProcessOptions \relax

\LoadClass[a4paper,10pt]{report}

\RequirePackage{geometry}
\geometry{a4paper,left=1.3in,top=1.3in,right=0.7in,bottom=0.7in,headheight=13.6pt,includefoot,footskip=\dimexpr\headsep+\ht\strutbox\relax}
\RequirePackage[pdfborder={0 0 0},colorlinks=false]{hyperref}
\RequirePackage{ifpdf}
\ifpdf
\RequirePackage[pdftex]{graphicx,color}
\else
\RequirePackage{graphicx,color}
\fi
\RequirePackage[font=small,labelfont=normalfont,textfont=normalfont,singlelinecheck=off,justification=centering]{caption}
\RequirePackage[font=small,labelfont=normalfont,textfont=normalfont,singlelinecheck=off,justification=centering]{subcaption}
\RequirePackage{amsmath,amssymb,amsthm,array}
\RequirePackage[titletoc,title]{appendix}
\RequirePackage{abstract}
\RequirePackage{textcase}
\RequirePackage{sectsty}
\RequirePackage{setspace}
\RequirePackage{alltt}
\RequirePackage{xifthen}

\setcounter{secnumdepth}{3}
\setlength\itemsep{0pt}

\partfont{\LARGE\centering\MakeTextUppercase}
\chapterfont{\Large\centering\MakeTextUppercase}
\chaptertitlefont{\Large\centering\MakeTextUppercase}
\sectionfont{\large\MakeTextUppercase}
\subsectionfont{\large}

\setlength{\abovecaptionskip}{6pt}
\setlength{\belowcaptionskip}{6pt}

\renewcommand{\arraystretch}{1.3}

\renewcommand{\bibname}{References}
\renewcommand{\contentsname}{Table of Contents}
\addtocontents{toc}{\protect{\pdfbookmark[0]{\contentsname}{toc}}}

\renewcommand{\abstractnamefont}{\Large\bfseries\MakeTextUppercase}
\renewcommand{\abstracttextfont}{\normalfont}

\newcommand\@logo{}
\newcommand\logo[1]{\renewcommand\@logo{#1}}

\newif\if@supervisor  \@supervisorfalse
\def\supervisor#1{\gdef\@supervisor{#1}\@supervisortrue}

\newif\if@cosupervisor  \@cosupervisorfalse
\def\cosupervisor#1{\gdef\@cosupervisor{#1}\@cosupervisortrue}

\newif\if@acknowledgement  \@acknowledgementfalse
\def\acknowledgement#1{\gdef\@acknowledgement{#1}\@acknowledgementtrue}

% \renewcommand*{\thefootnote}{\fnsymbol{footnote}}

\makeatletter
\renewcommand{\maketitle}{%
  \let\footnotesize\small
%   \let\footnoterule\relax
%   \let\footnote\thanks
  \begin{center}
    \LARGE{\textbf{\MakeUppercase \@title}}  \\ \vspace{1cm}
    \@logo \\ 
    \large{A thesis submitted by \\[2ex] \textbf{\@author}} \\ \vspace{1cm}
    \ifx\@cosupervisor\@empty 
     \begin{tabular*}{\textwidth}{c @{\extracolsep{\fill}} cc}
     & \textbf{Supervisor} & \\
     & \@supervisor & \\[2cm]
     \end{tabular*}
    \else
     \begin{tabular*}{\textwidth}{c @{\extracolsep{\fill}} cc}
     \textbf{Supervisor} &  & \textbf{Co-Supervisor} \\
     \@supervisor &  & \@cosupervisor \\[2cm]
     \end{tabular*}
    \fi
    \large{Submitted in the partial fulfillment of the requirements for the degree of Bachelor of Engineering in Electronics} \\ \vspace{1.5cm}
    \large{Faculty of Electrical, Electronics \& Computer Engineering} \\[2ex]
    \large{MEHRAN UNIVERSITY OF ENGINEERING \& TECHNOLOGY, JAMSHORO} \\ \vspace{1.5cm}
    \large{\@date}
  \end{center}
  \par
  \@thanks
  \vfill\null\setcounter{footnote}{0}
  \thispagestyle{empty}\addtocounter{page}{-1}
  
  \newpage
  \begin{center}
    \Large{\textbf{\MakeUppercase{Certificate}}}  \\ \vspace{0.5cm}
  \end{center}
  
  \begin{figure}
      \centering
      \includegraphics{logo.eps}
      
  \end{figure}
  
  \large{This is to certify that Project/Thesis Report on, ``\textbf{\@title}'' is submitted in partial fulfillment of the requirement for the degree of Bachelor of Electronic Engineering by the following students:
  
      \fi} \\[6ex]
  \begin{center}
  \begin{tabular}{c}
  \textbf{\@author} \\[16ex]
  \end{tabular}
  
  \ifx\@cosupervisor\@empty 
     \begin{tabular*}{\textwidth}{c @{\extracolsep{\fill}} cc}
     & \textbf{Supervisor} & \\
     & \@supervisor & \\[2cm]
     \end{tabular*}
    \else
     \begin{tabular*}{\textwidth}{c @{\extracolsep{\fill}} cc}
     \rule{0.3\textwidth}{0.4pt} & & \rule{0.3\textwidth}{0.4pt} \\
     \textbf{Supervisor} &  & \textbf{Co-Supervisor} \\
     \@supervisor &  & \@cosupervisor \\[2cm]
     \end{tabular*}
    \fi
  
  \begin{tabular}[x]{@{}c@{}}
  \rule{0.6\textwidth}{0.4pt} & 
  (Chairman, Department of Electronic Engineering)\end{tabular} \\
  \end{tabular}
  \end{center}
  \vspace{1.5cm}
  Date: \rule{0.2\textwidth}{0.4pt}
  \thispagestyle{empty}\addtocounter{page}{-1}
  \ifx\@acknowledgement\@empty
  \else
   \newpage
   \begin{center}
     \Large{\textbf{\MakeUppercase{Acknowledgment}}}  \\ \vspace{1cm}
   \end{center}
   \large{\@acknowledgement}
  \fi
}
\makeatother

\makeatletter
\renewenvironment{abstract}{%
  \newpage
    \begin{center}
      \Large{\textbf{\MakeUppercase{\abstractname}}} \\ \vspace{1cm}
    \end{center}}
\makeatother
